@@ -6,6 +6,9 @@ fn main() {
     if target.contains("freebsd") {
         if env::var("RUST_STD_FREEBSD_12_ABI").is_ok() {
             println!("cargo:rustc-cfg=freebsd12");
+        } else if env::var("RUST_STD_FREEBSD_13_ABI").is_ok() {
+            println!("cargo:rustc-cfg=freebsd12");
+            println!("cargo:rustc-cfg=freebsd13");
         }
     } else if target.contains("linux")
         || target.contains("netbsd")
@@ -31,6 +34,7 @@ fn main() {
         || target.contains("espidf")
         || target.contains("solid")
         || target.contains("nintendo-3ds")
+        || target.contains("vita")
         || target.contains("nto")
     {
         // These platforms don't have any special requirements.
